@@ -4,11 +4,10 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 use Database::Migrator 0.07;
 use Database::Migrator::Types qw( HashRef Str );
-use File::Slurp qw( read_file );
 use Pg::CLI 0.11;
 use Pg::CLI::createdb;
 use Pg::CLI::dropdb;
@@ -48,30 +47,30 @@ has _cli_constructor_args => (
 sub _create_database {
     my $self = shift;
 
-    my $database = $self->database();
+    my $database = $self->database;
 
-    $self->logger()->info("Creating the $database database");
+    $self->logger->info("Creating the $database database");
 
     my @opts;
-    push @opts, '--encoding', $self->encoding()
-        if $self->_has_encoding();
-    push @opts, '--locale', $self->locale()
-        if $self->_has_locale();
-    push @opts, '--lc-collate', $self->lc_collate()
-        if $self->_has_lc_collate();
-    push @opts, '--lc-ctype', $self->lc_ctype()
-        if $self->_has_lc_ctype();
-    push @opts, '--owner', $self->owner()
-        if $self->_has_owner();
-    push @opts, '--tablespace', $self->tablespace()
-        if $self->_has_tablespace();
-    push @opts, '--template', $self->template()
-        if $self->_has_template();
+    push @opts, '--encoding', $self->encoding
+        if $self->_has_encoding;
+    push @opts, '--locale', $self->locale
+        if $self->_has_locale;
+    push @opts, '--lc-collate', $self->lc_collate
+        if $self->_has_lc_collate;
+    push @opts, '--lc-ctype', $self->lc_ctype
+        if $self->_has_lc_ctype;
+    push @opts, '--owner', $self->owner
+        if $self->_has_owner;
+    push @opts, '--tablespace', $self->tablespace
+        if $self->_has_tablespace;
+    push @opts, '--template', $self->template
+        if $self->_has_template;
 
     $self->_run_cli_or_die(
         'createdb',
         'run',
-        database => $self->database(),
+        database => $self->database,
         options  => \@opts,
     );
 
@@ -85,8 +84,9 @@ sub _run_ddl {
     $self->_run_cli_or_die(
         'psql',
         'execute_file',
-        database => $self->database(),
+        database => $self->database,
         file     => $file,
+        options  => [ -v => 'ON_ERROR_STOP=1' ],
     );
 
     return;
@@ -95,14 +95,14 @@ sub _run_ddl {
 sub _drop_database {
     my $self = shift;
 
-    my $database = $self->database();
+    my $database = $self->database;
 
-    $self->logger()->info("Dropping the $database database");
+    $self->logger->info("Dropping the $database database");
 
     $self->_run_cli_or_die(
         'dropdb',
         'run',
-        database => $self->database(),
+        database => $self->database,
         options  => ['--if-exists'],
     );
 
@@ -119,7 +119,7 @@ sub _run_cli_or_die {
 
     my $stdout;
     my $stderr;
-    $self->$cli_obj_method()->$method(
+    $self->$cli_obj_method->$method(
         %args,
         stdout => \$stdout,
         stderr => \$stderr,
@@ -133,13 +133,13 @@ sub _run_cli_or_die {
 sub _createdb {
     my $self = shift;
 
-    return Pg::CLI::createdb->new( $self->_cli_constructor_args() );
+    return Pg::CLI::createdb->new( $self->_cli_constructor_args );
 }
 
 sub _dropdb {
     my $self = shift;
 
-    return Pg::CLI::dropdb->new( $self->_cli_constructor_args() );
+    return Pg::CLI::dropdb->new( $self->_cli_constructor_args );
 }
 ## use critic
 
@@ -147,7 +147,7 @@ sub _build_psql {
     my $self = shift;
 
     return Pg::CLI::psql->new(
-        %{ $self->_cli_constructor_args() },
+        %{ $self->_cli_constructor_args },
         quiet => 1,
     );
 }
@@ -157,8 +157,8 @@ sub _build_cli_constructor_args {
 
     my %args;
     for my $m (qw( username password host port )) {
-        $args{$m} = $self->$m()
-            if defined $self->$m();
+        $args{$m} = $self->$m
+            if defined $self->$m;
     }
 
     return \%args;
@@ -179,7 +179,7 @@ around _build_dbh => sub {
 sub _driver_name {'Pg'}
 ## use critic
 
-__PACKAGE__->meta()->make_immutable();
+__PACKAGE__->meta->make_immutable;
 
 1;
 
@@ -189,13 +189,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Database::Migrator::Pg - Database::Migrator implementation for Postgres
 
 =head1 VERSION
 
-version 0.05
+version 0.06
 
 =head1 SYNOPSIS
 
@@ -264,13 +266,31 @@ Please submit bugs to the CPAN RT system at
 http://rt.cpan.org/NoAuth/Bugs.html?Dist=Database-Migrator-Pg or via email at
 bug-database-migrator-pg@rt.cpan.org.
 
+Bugs may be submitted through L<https://github.com/maxmind/Database-Migrator-Pg/issues>.
+
 =head1 AUTHOR
 
 Dave Rolsky <autarch@urth.org>
 
+=head1 CONTRIBUTORS
+
+=for stopwords Gregory Oschwald Kevin Phair
+
+=over 4
+
+=item *
+
+Gregory Oschwald <goschwald@maxmind.com>
+
+=item *
+
+Kevin Phair <phair.kevin@gmail.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2015 by MaxMind, Inc..
+This software is Copyright (c) 2013 - 2017 by MaxMind, Inc.
 
 This is free software, licensed under:
 
